==> JDFLibJ-2.1.7.40-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/xjdftojdf/XJDFPrepWalker.java <==
/*
 * The CIP4 Software License, Version 1.0
 *
 *
 * Copyright (c) 2001-2022 The International Cooperation for the Integration of Processes in Prepress, Press and Postpress (CIP4). All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution, if any, must include the following acknowledgment: "This product includes software developed by the The International Cooperation for
 * the Integration of Processes in Prepress, Press and Postpress (www.cip4.org)" Alternately, this acknowledgment mrSubRefay appear in the software itself, if and wherever such third-party
 * acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of Processes in Prepress, Press and Postpress" must not be used to endorse or promote products derived from this software
 * without prior written permission. For written permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4", nor may "CIP4" appear in their name, without prior writtenrestartProcesses() permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIrSubRefAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE. ====================================================================
 *
 * This software consists of voluntary contributions made by many individuals on behalf of the The International Cooperation for the Integration of Processes in Prepress, Press and Postpress and was
 * originally based on software restartProcesses() copyright (c) 1999-2001, Heidelberger Druckmaschinen AG copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the Integration of Processes in Prepress, Press and Postpress , please see <http://www.cip4.org/>.
 *
 */
package org.cip4.jdflib.extensions.xjdfwalker.xjdftojdf;

import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.core.VString;
import org.cip4.jdflib.elementwalker.BaseElementWalker;
import org.cip4.jdflib.elementwalker.BaseWalker;
import org.cip4.jdflib.elementwalker.BaseWalkerFactory;
import org.cip4.jdflib.extensions.ResourceHelper;
import org.cip4.jdflib.extensions.SetHelper;
import org.cip4.jdflib.extensions.XJDFConstants;

/**
 * some generic preprocessing that is better done on the XJDF prior to XJDF--> JDF Conversion
 *
 * @author Rainer Prosi, Heidelberger Druckmaschinen *
 */
class XJDFPrepWalker extends BaseElementWalker
{

	/**
	 * @param newRoot
	 */
	XJDFPrepWalker()
	{
		super(new BaseWalkerFactory());
	}

	/**
	 * @author Rainer Prosi, Heidelberger Druckmaschinen
	 */
	protected class WalkElement extends BaseWalker
	{

		@SuppressWarnings("synthetic-access")
		public WalkElement()
		{
			super(getFactory());
		}

		/**
		 * @param xjdf
		 * @return true if must continue
		 */
		@Override
		public KElement walk(final KElement xjdf, final KElement dummy)
		{
			return xjdf;
		}

	}

	/**
	 * @author Rainer Prosi, Heidelberger Druckmaschinen
	 */
	protected class WalkResourceInfo extends WalkElement
	{

		public WalkResourceInfo()
		{
			super();
		}

		/**
		 * @param xjdf
		 * @return true if must continue
		 */
		@Override
		public KElement walk(final KElement xjdf, final KElement dummy)
		{
			KElement parent = xjdf.getParentNode_KElement();
			if (parent != null)
			{
				SetHelper sh = SetHelper.getHelper(xjdf.getElement(XJDFConstants.ResourceSet));
				if (sh != null)
				{
					for (int i = 1; i < sh.size();)
					{
						KElement newRI = parent.appendElement(ElementName.RESOURCEINFO);
						newRI.setAttributes(xjdf);
						KElement newSet = newRI.appendElement(XJDFConstants.ResourceSet);
						newSet.setAttributes(sh.getRoot());
						ResourceHelper part = sh.getPartition(i);
						newSet.moveElement(part.getRoot(), null);
					}
				}
			}
			return super.walk(xjdf, dummy);
		}

		@Override
		public VString getElementNames()
		{
			return new VString(ElementName.RESOURCEINFO);
		}

	}

}

==> JDFLibJ-2.1.7.46-sources.jar: org/cip4/jdflib/extensions/xjdfwalker/xjdftojdf/XJDFPrepWalker.java <==
/*
 * The CIP4 Software License, Version 1.0
 *
 *
 * Copyright (c) 2001-2022 The International Cooperation for the Integration of Processes in Prepress, Press and Postpress (CIP4). All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the
 * distribution.
 *
 * 3. The end-user documentation included with the redistribution, if any, must include the following acknowledgment: "This product includes software developed by the The International Cooperation for
 * the Integration of Processes in Prepress, Press and Postpress (www.cip4.org)" Alternately, this acknowledgment mrSubRefay appear in the software itself, if and wherever such third-party
 * acknowledgments normally appear.
 *
 * 4. The names "CIP4" and "The International Cooperation for the Integration of Processes in Prepress, Press and Postpress" must not be used to endorse or promote products derived from this software
 * without prior written permission. For written permission, please contact info@cip4.org.
 *
 * 5. Products derived from this software may not be called "CIP4", nor may "CIP4" appear in their name, without prior writtenrestartProcesses() permission of the CIP4 organization
 *
 * Usage of this software in commercial products is subject to restrictions. For details please consult info@cip4.org.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE INTERNATIONAL COOPERATION FOR THE INTEGRATION OF PROCESSES IN PREPRESS, PRESS AND POSTPRESS OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIrSubRefAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE. ====================================================================
 *
 * This software consists of voluntary contributions made by many individuals on behalf of the The International Cooperation for the Integration of Processes in Prepress, Press and Postpress and was
 * originally based on software restartProcesses() copyright (c) 1999-2001, Heidelberger Druckmaschinen AG copyright (c) 1999-2001, Agfa-Gevaert N.V.
 *
 * For more information on The International Cooperation for the Integration of Processes in Prepress, Press and Postpress , please see <http://www.cip4.org/>.
 *
 */
package org.cip4.jdflib.extensions.xjdfwalker.xjdftojdf;

import java.util.List;

import org.cip4.jdflib.core.ElementName;
import org.cip4.jdflib.core.KElement;
import org.cip4.jdflib.core.StringArray;
import org.cip4.jdflib.core.VString;
import org.cip4.jdflib.elementwalker.BaseElementWalker;
import org.cip4.jdflib.elementwalker.BaseWalker;
import org.cip4.jdflib.elementwalker.BaseWalkerFactory;
import org.cip4.jdflib.extensions.ResourceHelper;
import org.cip4.jdflib.extensions.SetHelper;
import org.cip4.jdflib.extensions.XJDFConstants;
import org.cip4.jdflib.extensions.xjdfwalker.jdftoxjdf.JDFToXJDFDataCache;

/**
 * some generic preprocessing that is better done on the XJDF prior to XJDF--> JDF Conversion
 *
 * @author Rainer Prosi, Heidelberger Druckmaschinen *
 */
class XJDFPrepWalker extends BaseElementWalker
{

	/**
	 * @param newRoot
	 */
	XJDFPrepWalker()
	{
		super(new BaseWalkerFactory());
	}

	/**
	 * @author Rainer Prosi, Heidelberger Druckmaschinen
	 */
	protected class WalkElement extends BaseWalker
	{

		@SuppressWarnings("synthetic-access")
		public WalkElement()
		{
			super(getFactory());
		}

		/**
		 * @param xjdf
		 * @return true if must continue
		 */
		@Override
		public KElement walk(final KElement xjdf, final KElement dummy)
		{
			return xjdf;
		}

	}

	/**
	 * @author Rainer Prosi, Heidelberger Druckmaschinen
	 */
	protected class WalkResourceInfo extends WalkElement
	{

		public WalkResourceInfo()
		{
			super();
		}

		/**
		 * @param xjdf
		 * @return true if must continue
		 */
		@Override
		public KElement walk(final KElement xjdf, final KElement dummy)
		{
			KElement parent = xjdf.getParentNode_KElement();
			if (parent != null)
			{
				SetHelper sh = SetHelper.getHelper(xjdf.getElement(XJDFConstants.ResourceSet));
				if (sh != null)
				{
					for (int i = 1; i < sh.size();)
					{
						KElement newRI = parent.appendElement(ElementName.RESOURCEINFO);
						newRI.setAttributes(xjdf);
						KElement newSet = newRI.appendElement(XJDFConstants.ResourceSet);
						newSet.setAttributes(sh.getRoot());
						ResourceHelper part = sh.getPartition(i);
						newSet.moveElement(part.getRoot(), null);
					}
				}
			}
			return super.walk(xjdf, dummy);
		}

		@Override
		public VString getElementNames()
		{
			return new VString(ElementName.RESOURCEINFO);
		}

	}

	/**
	 * @author Rainer Prosi, Heidelberger Druckmaschinen
	 */
	protected class WalkStripMark extends WalkElement
	{

		public WalkStripMark()
		{
			super();
		}

		/**
		 * @param xjdf
		 * @return true if must continue
		 */
		@Override
		public KElement walk(final KElement xjdf, final KElement dummy)
		{
			List<KElement> kids = xjdf.getChildList();
			StringArray names = JDFToXJDFDataCache.getStripMarkElements();
			for (KElement kid : kids)
			{
				if (names.contains(kid.getLocalName()))
				{
					KElement parent = xjdf.getParentNode_KElement();

					KElement mo = parent.getElement("PlacedObject/MarkObject");
					if (mo == null)
					{
						KElement po = parent.insertBefore(XJDFConstants.PlacedObject, xjdf, null);
						mo = po.appendElement(ElementName.MARKOBJECT);
					}
					for (KElement kid2 : kids)
						mo.moveElement(kid2, null);
					KElement dm = mo.appendElement(ElementName.DEVICEMARK);
					dm.setAttributes(xjdf);
					xjdf.deleteNode();
					return super.walk(mo, dummy);
				}
			}
			return super.walk(xjdf, dummy);
		}

		@Override
		public VString getElementNames()
		{
			return new VString(ElementName.STRIPMARK);
		}

	}

}
